==> swf-visualizer-0.1.1.tgz: package/src/components/visualizer-info/visualization-container/visualization-menu-config/color-option/color-option.jsx <==
import React, { useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { getEndpointBaseURL } from '@services/environment';
import { fetchColorOptionsAPIData } from '@store/actions/colors-option-api-actions';

import AccordionItem from '../../../../../../shared/accordion-item';
import Loader from '../../../../../../shared/loader/loader';
import ColorsTexture from './colors-texture/colors-texture'

import './color-option.scss';

const ColorOption = ({ optionType }) => {

  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  const colorsOptionData = useSelector((state) => state.colorOptions);
  const dispatch = useDispatch();

  useEffect(() => {
    const paramType = optionType === 1 ? 'c' : 'o';
    const fetchProductColorOptionsData = async () => {
      try {
        const url = `${getEndpointBaseURL()}productColorOptions/${defaultProduct?.id}/${paramType}`;
        await dispatch(fetchColorOptionsAPIData(url));
      } catch (error) {
        console.error('Error fetching product color options data:', error);
      } 
    };

    fetchProductColorOptionsData();
  }, []);

  return (
    <div className='color-option-container'>
      {colorsOptionData.loading && <Loader />}
      {colorsOptionData?.colorOptionsData && (
        <div className="color-option-aside">
          <AccordionItem
            accordionOption={colorsOptionData?.colorOptionsData}
            optionType={optionType}
          />
        </div>
      )}

      {optionType === 1 && (
       <ColorsTexture />
      )}
    </div>
  );
};

export default ColorOption;

==> swf-visualizer-0.1.3.tgz: package/src/components/visualizer-info/visualization-container/visualization-menu-config/color-option/color-option.jsx <==
import React, { useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { getEndpointBaseURL } from '@services/environment';
import { fetchColorOptionsAPIData } from '@store/actions/colors-option-api-actions';

import AccordionItem from '@shared/accordion-item';
import Loader from '@shared/loader/loader';
import ColorsTexture from './colors-texture/colors-texture'

import './color-option.scss';

const ColorOption = ({ optionType }) => {

  const defaultProduct = useSelector((state) => state.savedProjects.defaultProduct);
  const colorsOptionData = useSelector((state) => state.colorOptions);
  const dispatch = useDispatch();

  useEffect(() => {
    const paramType = optionType === 1 ? 'c' : 'o';
    const fetchProductColorOptionsData = async () => {
      try {
        const url = `${getEndpointBaseURL()}productColorOptions/${defaultProduct?.id}/${paramType}`;
        await dispatch(fetchColorOptionsAPIData(url));
      } catch (error) {
        console.error('Error fetching product color options data:', error);
      } 
    };

    fetchProductColorOptionsData();
  }, []);

  return (
    <div className='color-option-container'>
      {colorsOptionData.loading && <Loader />}
      {colorsOptionData?.colorOptionsData && (
        <div className="color-option-aside">
          <AccordionItem
            accordionOption={colorsOptionData?.colorOptionsData}
            optionType={optionType}
          />
        </div>
      )}

      {optionType === 1 && (
       <ColorsTexture />
      )}
    </div>
  );
};

export default ColorOption;
